/**
*  An object that contains a reference to a Object object and a
*  reference to another Node. Allows a Node to be inserted into a list
*  at construction. Supports linking a subsequent object to this Node,
*  will return the reference to the next Node, or the reference to the
*  data Object. However, <b>the data object is immutable once
*  the object is constructed.</b>
*
*  <b>Students are not allowed to modify this class</b>
*/


public class Node implements Comparable
{

   private Comparable value;
   private Node next;

   /**
   *  constructor builds the Node with the supplied parameter
   *
   *  @param data object (must be Object)
   */

   public Node(Comparable initValue)
   {
      this(initValue, null);
   }

   /**
   *  constructor builds the Node with the supplied parameters
   *
   *  @param data object (must be Object)
   *  @param link  to a next Node, or null
   */

   public Node(Comparable initValue, Node initNext)
   {
      value = initValue;
      next = initNext;
   }

   /**
   *  returns reference to the next Node
   *
   *  @return next reference
   */

   public Node getNext()
   {
      return next;
   }


   /**
   *  sets the next reference of this object to the paramter object
   *
   *  @param next Node
   */

   public void setNext(Node obj)
   {

      next = obj;
   }

   /**
   *  returns reference to the data value of the object
   *
   *  @return Object reference
   */

   public Comparable getData()
   {

      return value;
   }

   /**
   *  returns reference to the data value of the object
   *
   *  @return 1, 0, or -1
   */

   public int compareTo(Object obj)
   {
         return (getData().compareTo(((Node)obj).getData()));
   }

   /**
   *  returns string representation of the object
   *
   *  @return String reference
   */

   public String toString()
   {
      return value.toString();
   }
}
